@@ -21,13 +21,15 @@ OC.L10N.register(
     "Deleted" : "Lamet",
     "Restore" : "Adkrouiñ",
     "Delete permanently" : "Lamet da viken",
+    "Empty trash bin" : "Pod-lastez goullo",
+    "Cancel" : "Arrest",
+    "Close" : "Seriñ",
     "[Yesterday]" : "[Dec'h]",
     "[Today]" : "[Hiziv]",
     "[Tomorrow]" : "[Warc'hoazh]",
-    "Cancel" : "Arrest",
-    "Close" : "Seriñ",
     "Tomorrow" : "Warc'hoaz",
     "Details" : "Munudoù",
+    "Notes" : "Notennoù",
     "When shared show full event" : "Diskouez an darvoud a-bezh pa vez lodet",
     "When shared show only busy" : "Diskouez hepken ar re pres warno pa vez lodet",
     "When shared hide this event" : "Kuzhat an darvoud-mañ pa vez lodet",
