@@ -22,10 +22,15 @@ OC.L10N.register(
     "Delete" : "Kustuta",
     "Unshare" : "Lõpeta jagamine",
     "An empty name is not allowed." : "Nime lahter ei tohi olla tühi.",
+    "Trash bin" : "Prügikast",
     "Name" : "Nimi",
     "Deleted" : "Kustutatud",
     "Restore" : "Taasta",
     "Delete permanently" : "Kustuta jäädavalt",
+    "Empty trash bin" : "Tühjenda prügikast",
+    "Cancel" : "Loobu",
+    "Close" : "Sulge",
+    "Select tags to filter by" : "Vali sildid, mille järgi filtreerida",
     "Change sort order" : "Muuda sorteerimisjärjekorda",
     "Start date" : "Alguskuupäev",
     "Due date" : "Tähtaeg",
@@ -34,8 +39,6 @@ OC.L10N.register(
     "Alphabetically" : "Tähestikujärjekorras",
     "Manually" : "Käsitsi",
     "Task is completed" : "Ülesanne on tehtud",
-    "Cancel" : "Loobu",
-    "Close" : "Sulge",
     "_%n Completed Task_::_%n Completed Tasks_" : ["%n lõpetatud ülesanne","%n lõpetatud ülesannet"],
     "Tomorrow" : "Homme",
     "All day" : "Kogu päev",
