@@ -39,11 +39,12 @@ OC.L10N.register(
     "An empty name is not allowed." : "שדה שם ריק אינו מותר.",
     "An error occurred, unable to delete the calendar." : "אירעה שגיאה, לא ניתן למחוק את היומן.",
     "An error occurred, unable to delete the list." : "אירעה שגיאה, אין אפשרות למחוק את הרשימה.",
-    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["לוח השנה יימחק בעוד שנייה","לוח השנה יימחק בעוד {countdown} שניות","לוח השנה יימחק בעוד {countdown} שניות","לוח השנה יימחק בעוד {countdown} שניות"],
-    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["שיתוף לוח השנה יפסק בעוד שנייה","שיתוף לוח השנה יפסק בעוד {countdown} שניות","שיתוף לוח השנה יפסק בעוד {countdown} שניות","שיתוף לוח השנה יפסק בעוד {countdown} שניות"],
+    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["לוח השנה יימחק בעוד שנייה","לוח השנה יימחק בעוד {countdown} שניות","לוח השנה יימחק בעוד {countdown} שניות"],
+    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["שיתוף לוח השנה יפסק בעוד שנייה","שיתוף לוח השנה יפסק בעוד {countdown} שניות","שיתוף לוח השנה יפסק בעוד {countdown} שניות"],
     "_Deleting the list in {countdown} second_::_Deleting the list in {countdown} seconds_" : ["הרשימה תימחק בעוד שנייה","הרשימה תימחק בעוד שתי שניות","הרשימה תימחק בעוד {countdown} שניות","הרשימה תימחק בעוד {countdown} שניות"],
-    "_Unsharing the list in {countdown} second_::_Unsharing the list in {countdown} seconds_" : ["שיתוף הרשומה יבוטל בעוד שנייה אחת","שיתוף הרשומה יבוטל בעוד שתי שניות","שיתוף הרשומה יבוטל בעוד {countdown} שניות","שיתוף הרשומה יבוטל בעוד {countdown} שניות"],
+    "_Unsharing the list in {countdown} second_::_Unsharing the list in {countdown} seconds_" : ["שיתוף הרשומה יבוטל בעוד שנייה אחת","שיתוף הרשומה יבוטל בעוד שתי שניות","שיתוף הרשומה יבוטל בעוד {countdown} שניות"],
     "_Shared with {num} entity_::_Shared with {num} entities_" : ["משותף עם ישות אחת","משותף עם {num} ישויות","משותף עם {num} ישויות","משותף עם {num} ישויות"],
+    "Trash bin" : "אשפה",
     "Name" : "שם",
     "Deleted" : "נמחק",
     "Restore" : "שחזור",
@@ -51,14 +52,22 @@ OC.L10N.register(
     "Empty trash bin" : "פינוי סל האשפה",
     "Untitled task" : "משימה ללא כותרת",
     "Untitled event" : "אירוע ללא כותרת",
+    "Untitled item" : "פריט ללא כותרת",
+    "Unknown calendar" : "לוח שנה לא ידוע",
+    "Could not load deleted calendars and objects" : "לא ניתן לטעון לוחות שנה ופריטים מחוקים",
+    "Could not restore calendar or event" : "לא ניתן לשחזר לוח שנה או אירוע",
+    "Do you really want to empty the trash bin?" : "האם אמת בכוונתך לרוקן את סל האשפה?",
     "Select a calendar" : "הגדרת יומן",
+    "Cancel" : "ביטול",
+    "Close" : "סגירה",
     "Delete all completed tasks." : "מחיקת כל המשימות שהושלמו.",
     "Delete completed tasks." : "מחיקת המשימות שהושלמו.",
     "Deleted all completed tasks from calendar \"{calendar}\"." : "כל המשימות שהושלמו נמחקו מהיומן „{calendar}”.",
     "No errors" : "אין שגיאות",
     "Open your browser console for more details" : "נא לפתוח את המסוף של הדפדפן שלך לקבלת פרטים נוספים",
-    "_This will delete {taskCount} completed task and its subtasks from calendar \"{calendar}\"._::_This will delete {taskCount} completed tasks and their subtasks from calendar \"{calendar}\"._" : ["פעולה זו תמחק משימה שהושלמה ואת תת־המשימות שלה מהיומן „{calendar}”.","פעולה זו תמחק {taskCount} משימות שהושלמו ואת תת־המשימות שלהן מהיומן „{calendar}”.","פעולה זו תמחק {taskCount} משימות שהושלמו ואת תת־המשימות שלהן מהיומן „{calendar}”.","פעולה זו תמחק {taskCount} משימות שהושלמו ואת תת־המשימות שלהן מהיומן „{calendar}”."],
-    "_Could not delete {failedCount} task._::_Could not delete {failedCount} tasks._" : ["לא ניתן למחוק משימה אחת.","לא ניתן למחוק {failedCount} משימות.","לא ניתן למחוק {failedCount} משימות.","לא ניתן למחוק {failedCount} משימות."],
+    "_This will delete {taskCount} completed task and its subtasks from calendar \"{calendar}\"._::_This will delete {taskCount} completed tasks and their subtasks from calendar \"{calendar}\"._" : ["פעולה זו תמחק משימה שהושלמה ואת תת־המשימות שלה מהיומן „{calendar}”.","פעולה זו תמחק {taskCount} משימות שהושלמו ואת תת־המשימות שלהן מהיומן „{calendar}”.","פעולה זו תמחק {taskCount} משימות שהושלמו ואת תת־המשימות שלהן מהיומן „{calendar}”."],
+    "_Could not delete {failedCount} task._::_Could not delete {failedCount} tasks._" : ["לא ניתן למחוק משימה אחת.","לא ניתן למחוק {failedCount} משימות.","לא ניתן למחוק {failedCount} משימות."],
+    "Select tags to filter by" : "תגיות נבחרות מסוננות על ידי",
     "Add an important task to \"{calendar}\"…" : "הוספת משימה חשובה אל „{calendar}”",
     "Add a task due today to \"{calendar}\"…" : "הוספה משימה שמועד תפוגתה הוא היום אל „{calendar}”",
     "Add a current task to \"{calendar}\"…" : "הוספת משימה נוכחית אל „{calendar}”",
@@ -97,15 +106,12 @@ OC.L10N.register(
     "[Completed tomorrow at] LT" : "[תושלם מחר בשעה] LT",
     "[Completed] L [at] LT" : "[הושלמה] L [בשעה] LT",
     "Add a subtask to \"{task}\"…" : "הוספת תת־משימה אל „{task}”",
-    "_Deleting the task in {countdown} second_::_Deleting the task in {countdown} seconds_" : ["המשימה תימחק בעוד שנייה","המשימה תימחק בעוד {countdown} שניות","המשימה תימחק בעוד {countdown} שניות","המשימה תימחק בעוד {countdown} שניות"],
+    "_Deleting the task in {countdown} second_::_Deleting the task in {countdown} seconds_" : ["המשימה תימחק בעוד שנייה","המשימה תימחק בעוד {countdown} שניות","המשימה תימחק בעוד {countdown} שניות"],
     "Task is completed" : "המשימה הושלמה",
-    "Cancel" : "ביטול",
-    "Close" : "סגירה",
     "_%n Completed Task_::_%n Completed Tasks_" : ["%n פעילות מושלמת","%n פעילויות הושלמו","%n פעילויות הושלמו","%n פעילויות הושלמו"],
     "Tomorrow" : "מחר",
     "Add List…" : "הוספת רשימה…",
     "All day" : "כל היום",
-    "Edit title" : "עריכת כותרת",
     "Details" : "פרטים",
     "Select a classification" : "בחירת סיווג",
     "Select a status" : "בחירת מצב",
@@ -121,6 +127,33 @@ OC.L10N.register(
     "Canceled" : "מבוטלת",
     "Loading task from server." : "נטענת משימה מהשרת.",
     "Task not found!" : "לא אותרה משימה!",
+    "Set start date" : "קביעת תאריך התחלה",
+    "Set due date" : "הגדרת תאריך יעד",
+    "Priority {priority}: low" : "עדיפות {priority}: נמוכה",
+    "Priority {priority}: medium" : "עדיפות {priority}: בינונית",
+    "Priority {priority}: high" : "עדיפות {priority}: גבוהה",
+    "No priority assigned" : "לא הוגדרה עדיפות",
+    "{percent} % completed" : "{percent} % הושלמו",
+    "[Due today]" : "[מועד התפוגה הוא היום]",
+    "[Due tomorrow]" : "[מועד התפוגה הוא מחר]",
+    "[Due today at] LT" : "[מועד התפוגה הוא היום בשעה] LT",
+    "[Due tomorrow at] LT" : "[מועד התפוגה הוא מחר בשעה] LT",
+    "Successfully created the task." : "המשימה נוצרה בהצלחה.",
+    "Could not delete the task." : "לא ניתן למחוק את המשימה.",
+    "Synchronizing to the server." : "מתבצע סנכרון מול השרת.",
+    "Task successfully saved to server." : "המשימה נשמרה לשרת בהצלחה.",
+    "Could not update the task because it was changed on the server. Please click to refresh it, local changes will be discarded." : "לא ניתן לעדכן את המשימה כיוון שהיא השתנתה בשרת. נא ללחוץ כדי לרענן אותה, השינויים המקומיים לא יישמרו.",
+    "Could not update the task." : "לא ניתן לעדכן את המשימה.",
+    "Successfully updated the task." : "המשימה עודכנה בהצלחה.",
+    "Task successfully moved to new calendar." : "המשימה הועברה בהצלחה ליומן חדש.",
+    "An error occurred" : "אירעה שגיאה",
+    "[Due on] LL" : "[מועד התפוגה הוא] LL",
+    "[Was due yesterday]" : "[מועד התפוגה היה אתמול]",
+    "[Was due on] LL" : "[מועד התפוגה היה] LL",
+    "[Was due today at] LT" : "[מועד התפוגה היה היום בשעה] LT",
+    "[Due on] LL [at] LT" : "[מועד התפוגה הוא] LL [בשעה] LT",
+    "[Was due yesterday at] LT" : "[מועד התפוגה היה אתמול בשעה] LT",
+    "[Was due on] LL [at] LT" : "[מועד התפוגה היה] LL [בשעה] LT",
     "[Starts today]" : "[מתחילה היום]",
     "[Starts tomorrow]" : "[מתחילה מחר]",
     "[Starts on] LL" : "[מתחילה במועד] LL",
@@ -131,33 +164,6 @@ OC.L10N.register(
     "[Starts tomorrow at] LT" : "[מתחילה מחר בשעה] LT",
     "[Starts on] LL [at] LT" : "[מתחילה ביום] LL [בשעה] LT",
     "[Started yesterday at] LT" : "[החלה אתמול בשעה] LT",
-    "[Started on] LL [at] LT" : "[החלה ביום] LL [בשעה] LT",
-    "Set start date" : "קביעת תאריך התחלה",
-    "[Due today]" : "[מועד התפוגה הוא היום]",
-    "[Due tomorrow]" : "[מועד התפוגה הוא מחר]",
-    "[Due on] LL" : "[מועד התפוגה הוא] LL",
-    "[Was due yesterday]" : "[מועד התפוגה היה אתמול]",
-    "[Was due on] LL" : "[מועד התפוגה היה] LL",
-    "[Was due today at] LT" : "[מועד התפוגה היה היום בשעה] LT",
-    "[Due today at] LT" : "[מועד התפוגה הוא היום בשעה] LT",
-    "[Due tomorrow at] LT" : "[מועד התפוגה הוא מחר בשעה] LT",
-    "[Due on] LL [at] LT" : "[מועד התפוגה הוא] LL [בשעה] LT",
-    "[Was due yesterday at] LT" : "[מועד התפוגה היה אתמול בשעה] LT",
-    "[Was due on] LL [at] LT" : "[מועד התפוגה היה] LL [בשעה] LT",
-    "Set due date" : "הגדרת תאריך יעד",
-    "Priority {priority}: low" : "עדיפות {priority}: נמוכה",
-    "Priority {priority}: medium" : "עדיפות {priority}: בינונית",
-    "Priority {priority}: high" : "עדיפות {priority}: גבוהה",
-    "No priority assigned" : "לא הוגדרה עדיפות",
-    "{percent} % completed" : "{percent} % הושלמו",
-    "Successfully created the task." : "המשימה נוצרה בהצלחה.",
-    "Could not delete the task." : "לא ניתן למחוק את המשימה.",
-    "Synchronizing to the server." : "מתבצע סנכרון מול השרת.",
-    "Task successfully saved to server." : "המשימה נשמרה לשרת בהצלחה.",
-    "Could not update the task because it was changed on the server. Please click to refresh it, local changes will be discarded." : "לא ניתן לעדכן את המשימה כיוון שהיא השתנתה בשרת. נא ללחוץ כדי לרענן אותה, השינויים המקומיים לא יישמרו.",
-    "Could not update the task." : "לא ניתן לעדכן את המשימה.",
-    "Successfully updated the task." : "המשימה עודכנה בהצלחה.",
-    "Task successfully moved to new calendar." : "המשימה הועברה בהצלחה ליומן חדש.",
-    "An error occurred" : "אירעה שגיאה"
+    "[Started on] LL [at] LT" : "[החלה ביום] LL [בשעה] LT"
 },
-"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");
+"nplurals=3; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: 2;");
