@@ -45,18 +45,22 @@ OC.L10N.register(
     "Empty trash bin" : "ゴミ箱を空にする",
     "Untitled task" : "タイトルなしタスク",
     "Untitled event" : "無題のイベント",
+    "Untitled item" : "無題の項目",
     "Unknown calendar" : "不明なカレンダー",
     "Could not load deleted calendars and objects" : "削除されたカレンダーとオブジェクトを読み込めませんでした。",
     "Could not restore calendar or event" : "カレンダーまたはイベントを復元できませんでした。",
     "Do you really want to empty the trash bin?" : "本当にゴミ箱を空にしますか？",
     "Select a calendar" : "カレンダーを選択",
     "Click here to add a note." : "クリックしてノートを追加",
+    "Cancel" : "キャンセル",
+    "Close" : "閉じる",
     "Delete all completed tasks." : "全ての完了したタスクを削除",
     "Delete completed tasks." : "完了したタスクを削除",
     "Deleted all completed tasks from calendar \"{calendar}\"." : "カレンダー \"{calendar}\" から完了したタスクをすべて削除しました。",
     "No errors" : "エラーはありません",
     "Open your browser console for more details" : "詳細はブラウザーコンソールを開きます",
     "_Could not delete {failedCount} task._::_Could not delete {failedCount} tasks._" : ["{failedCount} 個のタスクが削除できませんでした"],
+    "Select tags to filter by" : "フィルターするタグを選択してください",
     "Add an important task to \"{calendar}\"…" : "\"{calendar}\"に重要なタスクを追加する",
     "Add a task due today to \"{calendar}\"…" : "\"{calendar}\"に今日が期限のタスクを追加する",
     "Add a current task to \"{calendar}\"…" : "\"{calendar}\"に現在のタスクを追加する",
@@ -75,9 +79,9 @@ OC.L10N.register(
     "Sort by summary and priority." : "要約と優先順位で並べ替えます。",
     "Manually" : "手動",
     "Sort by manual order." : "手動で並べ替えます。",
-    "{complete} % completed" : "{complete} %完了",
     "Task is pinned" : "タスクはピンされています",
     "Task has a note" : "タスクにはノートがあります",
+    "{complete} % completed" : "{complete} %完了",
     "Add subtask" : "サブタスクを追加",
     "Show subtasks" : "サブタスクを表示",
     "Hide subtasks" : "サブタスクを非表示",
@@ -88,9 +92,7 @@ OC.L10N.register(
     "Add a subtask to \"{task}\"…" : "\"{task}\"にサブタスクを追加...",
     "Task is completed" : "タスク完了",
     "Create a new task" : "新しいタスクを作成する",
-    "Cancel" : "キャンセル",
     "Create task" : "タスクを作成する",
-    "Close" : "閉じる",
     "Open task" : "タスクを開く",
     "_%n Completed Task_::_%n Completed Tasks_" : ["完了済みタスク %n"],
     "Tomorrow" : "明日",
@@ -99,7 +101,6 @@ OC.L10N.register(
     "Unpin" : "ピンの解除",
     "Pin" : "ピン",
     "Show in Calendar" : "カレンダーに表示する",
-    "Edit title" : "タイトルを編集",
     "Details" : "詳細",
     "Select a classification" : "分類を選択",
     "Select a status" : "ステータスを選択",
@@ -115,14 +116,7 @@ OC.L10N.register(
     "Canceled" : "キャンセルされた",
     "Loading task from server." : "タスクをサーバーから読み込み中。",
     "Task not found!" : "タスクがありません！",
-    "[Starts today]" : "[今日開始]",
-    "[Starts tomorrow]" : "[明日開始]",
-    "[Started yesterday]" : "[昨日から]",
     "Set start date" : "開始日を設定",
-    "[Due today]" : "[今日まで]",
-    "[Due tomorrow]" : "[明日まで]",
-    "[Due on] LL" : "LL [まで]",
-    "[Was due yesterday]" : "[昨日が期限]",
     "Set due date" : "期限を設定",
     "Priority {priority}: low" : "優先度{priority}:低",
     "Priority {priority}: medium" : "優先度{priority}:中",
@@ -133,6 +127,8 @@ OC.L10N.register(
     "No tasks today" : "今日はタスクなし",
     "Mark as done" : "完了としてマーク",
     "No due date assigned" : "期限はありません",
+    "[Due today]" : "[今日まで]",
+    "[Due tomorrow]" : "[明日まで]",
     "[Due] L" : "L [まで]",
     "Successfully created the task." : "タスクの作成に成功しました",
     "Could not delete the task." : "タスクを削除できませんでした",
@@ -143,6 +139,11 @@ OC.L10N.register(
     "Successfully updated the task." : "タスクのアップデートに成功しました",
     "An error occurred" : "エラーが発生しました",
     "Create a task" : "タスクを作成する",
-    "Message from {author} in {conversationName}" : "{conversationName} で {author} からのメッセージ"
+    "Message from {author} in {conversationName}" : "{conversationName} で {author} からのメッセージ",
+    "[Due on] LL" : "LL [まで]",
+    "[Was due yesterday]" : "[昨日が期限]",
+    "[Starts today]" : "[今日開始]",
+    "[Starts tomorrow]" : "[明日開始]",
+    "[Started yesterday]" : "[昨日から]"
 },
 "nplurals=1; plural=0;");
