@@ -69,6 +69,8 @@ OC.L10N.register(
     "Delete date" : "Ištrinti datą",
     "Add this as a new tag" : "Pridėti tai kaip naują žymę",
     "No tag available. Create one!" : "Nėra prieinamų žymių. Sukurkite žymę!",
+    "Cancel" : "Atsisakyti",
+    "Close" : "Užverti",
     "Delete all completed tasks." : "Ištrinti visas atliktas užduotis.",
     "Delete completed tasks." : "Ištrinti atliktas užduotis.",
     "Deleted all completed tasks from calendar \"{calendar}\"." : "Ištrinti visas atliktas užduotis iš kalendoriaus \"{calendar}\".",
@@ -76,6 +78,7 @@ OC.L10N.register(
     "Open your browser console for more details" : "Išsamesnei informacijai, atverkite savo naršyklės pultą",
     "_This will delete {taskCount} completed task and its subtasks from calendar \"{calendar}\"._::_This will delete {taskCount} completed tasks and their subtasks from calendar \"{calendar}\"._" : ["Tai ištrins {taskCount} atliktą užduotį ir jos dalines užduotis iš kalendoriaus „{calendar}“.","Tai ištrins {taskCount} atliktas užduotis ir jų dalines užduotis iš kalendoriaus „{calendar}“.","Tai ištrins {taskCount} atliktų užduočių ir jų dalines užduotis iš kalendoriaus „{calendar}“.","Tai ištrins {taskCount} atliktą užduotį ir jų dalines užduotis iš kalendoriaus „{calendar}“."],
     "_Could not delete {failedCount} task._::_Could not delete {failedCount} tasks._" : ["Nepavyko ištrinti {failedCount} užduoties.","Nepavyko ištrinti {failedCount} užduočių.","Nepavyko ištrinti {failedCount} užduočių.","Nepavyko ištrinti {failedCount} užduoties."],
+    "Select tags to filter by" : "Pasirinkite žymes, pagal kurias filtruoti",
     "Add an important task to \"{calendar}\"…" : "Pridėti svarbią užduotį į „{calendar}“…",
     "Add a task due today to \"{calendar}\"…" : "Pridėti užduotį, kurios galutinis terminas šiandien į kalendorių „{calendar}“…",
     "Add a current task to \"{calendar}\"…" : "Pridėti dabartinę užduotį į „{calendar}“…",
@@ -107,10 +110,8 @@ OC.L10N.register(
     "Task is completed" : "Užduotis atlikta",
     "Task is read-only" : "Užduotis yra tik skaitymui",
     "Create a new task" : "Sukurti naują užduotį",
-    "Cancel" : "Atsisakyti",
     "Create task" : "Sukurti užduotį",
     "Creating the new task…" : "Kuriama nauja užduotis…",
-    "Close" : "Užverti",
     "Open task" : "Atverti užduotį",
     "\"{task}\" was added to \"{calendar}\"" : "„{task}“ buvo pridėta į „{calendar}“",
     "_%n Completed Task_::_%n Completed Tasks_" : ["%n atlikta užduotis","%n atliktos užduotys","%n atliktų užduočių","%n atlikta užduotis"],
@@ -120,7 +121,6 @@ OC.L10N.register(
     "Unpin" : "Atsegti",
     "Pin" : "Prisegti",
     "Show in Calendar" : "Rodyti kalendoriuje",
-    "Edit title" : "Redaguoti pavadinimą",
     "Details" : "Išsamiau",
     "Select a classification" : "Pasirinkite klasifikavimą",
     "Select a status" : "Pasirinkite būseną",
@@ -136,6 +136,36 @@ OC.L10N.register(
     "Canceled" : "Atsisakyta",
     "Loading task from server." : "Įkeliama užduotis iš serverio.",
     "Task not found!" : "Užduotis nerasta!",
+    "Set start date" : "Nustatyti pradžios datą",
+    "Set due date" : "Nustatyti galutinį terminą",
+    "Priority {priority}: low" : "Pirmenybė {priority}: žema",
+    "Priority {priority}: medium" : "Pirmenybė {priority}: vidutinė",
+    "Priority {priority}: high" : "Pirmenybė {priority}: aukšta",
+    "No priority assigned" : "Pirmenybė nepriskirta",
+    "{percent} % completed" : "{percent} % atlikta",
+    "No upcoming tasks" : "Artėjančių užduočių nėra",
+    "Mark as done" : "Žymėti kaip atliktą",
+    "[Due today]" : "[Galutinis terminas šiandien]",
+    "[Due tomorrow]" : "[Galutinis terminas rytoj]",
+    "[Due today at] LT" : "[Galutinis terminas šiandien] LT",
+    "[Due tomorrow at] LT" : "[Galutinis terminas rytoj] LT",
+    "Successfully created the task." : "Užduotis sėkmingai sukurta.",
+    "Could not delete the task." : "Nepavyko ištrinti užduoties.",
+    "Synchronizing to the server." : "Sinchronizuojama į serverį.",
+    "Task successfully saved to server." : "Užduotis sėkmingai įrašyta į serverį.",
+    "Could not update the task because it was changed on the server. Please click to refresh it, local changes will be discarded." : "Nepavyko atnaujinti užduoties, nes ji buvo pakeista serveryje. Spustelėkite, kad įkeltumėte ją iš naujo, vietiniai pakeitimai bus atmesti.",
+    "Could not update the task." : "Nepavyko atnaujinti užduoties.",
+    "Successfully updated the task." : "Užduotis sėkmingai atnaujinta.",
+    "Task successfully moved to new calendar." : "Užduotis sėkmingai perkelta į naują kalendorių.",
+    "An error occurred" : "Įvyko klaida",
+    "Create a task" : "Sukurti užduotį",
+    "[Due on] LL" : "[Galutinis terminas] LL",
+    "[Was due yesterday]" : "[Galutinis terminas buvo vakar]",
+    "[Was due on] LL" : "[Galutinis terminas buvo] LL",
+    "[Was due today at] LT" : "[Galutinis terminas buvo šiandien] LT",
+    "[Due on] LL [at] LT" : "[Galutinis terminas] LL, LT",
+    "[Was due yesterday at] LT" : "[Galutinis terminas buvo vakar] LT",
+    "[Was due on] LL [at] LT" : "[Galutinis terminas buvo] LL, LT",
     "[Starts today]" : "[Prasideda šiandien]",
     "[Starts tomorrow]" : "[Prasidės rytoj]",
     "[Starts on] LL" : "[Prasidės] LL",
@@ -146,36 +176,6 @@ OC.L10N.register(
     "[Starts tomorrow at] LT" : "[Prasidės rytoj] LT",
     "[Starts on] LL [at] LT" : "[Prasidės] LL, LT",
     "[Started yesterday at] LT" : "[Prasidėjo vakar] LT",
-    "[Started on] LL [at] LT" : "[Prasidėjo] LL, LT",
-    "Set start date" : "Nustatyti pradžios datą",
-    "[Due today]" : "[Galutinis terminas šiandien]",
-    "[Due tomorrow]" : "[Galutinis terminas rytoj]",
-    "[Due on] LL" : "[Galutinis terminas] LL",
-    "[Was due yesterday]" : "[Galutinis terminas buvo vakar]",
-    "[Was due on] LL" : "[Galutinis terminas buvo] LL",
-    "[Was due today at] LT" : "[Galutinis terminas buvo šiandien] LT",
-    "[Due today at] LT" : "[Galutinis terminas šiandien] LT",
-    "[Due tomorrow at] LT" : "[Galutinis terminas rytoj] LT",
-    "[Due on] LL [at] LT" : "[Galutinis terminas] LL, LT",
-    "[Was due yesterday at] LT" : "[Galutinis terminas buvo vakar] LT",
-    "[Was due on] LL [at] LT" : "[Galutinis terminas buvo] LL, LT",
-    "Set due date" : "Nustatyti galutinį terminą",
-    "Priority {priority}: low" : "Pirmenybė {priority}: žema",
-    "Priority {priority}: medium" : "Pirmenybė {priority}: vidutinė",
-    "Priority {priority}: high" : "Pirmenybė {priority}: aukšta",
-    "No priority assigned" : "Pirmenybė nepriskirta",
-    "{percent} % completed" : "{percent} % atlikta",
-    "No upcoming tasks" : "Artėjančių užduočių nėra",
-    "Mark as done" : "Žymėti kaip atliktą",
-    "Successfully created the task." : "Užduotis sėkmingai sukurta.",
-    "Could not delete the task." : "Nepavyko ištrinti užduoties.",
-    "Synchronizing to the server." : "Sinchronizuojama į serverį.",
-    "Task successfully saved to server." : "Užduotis sėkmingai įrašyta į serverį.",
-    "Could not update the task because it was changed on the server. Please click to refresh it, local changes will be discarded." : "Nepavyko atnaujinti užduoties, nes ji buvo pakeista serveryje. Spustelėkite, kad įkeltumėte ją iš naujo, vietiniai pakeitimai bus atmesti.",
-    "Could not update the task." : "Nepavyko atnaujinti užduoties.",
-    "Successfully updated the task." : "Užduotis sėkmingai atnaujinta.",
-    "Task successfully moved to new calendar." : "Užduotis sėkmingai perkelta į naują kalendorių.",
-    "An error occurred" : "Įvyko klaida",
-    "Create a task" : "Sukurti užduotį"
+    "[Started on] LL [at] LT" : "[Prasidėjo] LL, LT"
 },
 "nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
