@@ -6,6 +6,7 @@ OC.L10N.register(
     "All" : "бүх",
     "Current" : "Одоогийн",
     "Completed" : "Гүйцэтгэгдсэн",
+    "Tasks" : "Даалгавар",
     "Hidden" : "Далд",
     "Share with users or groups" : "Бусад хэрэглэгч, бүлэгт хуваалцах",
     "Can edit" : "Can edit",
@@ -19,9 +20,10 @@ OC.L10N.register(
     "Deleted" : "Устгагдсан",
     "Restore" : "Сэргээх",
     "Delete permanently" : "бүр мөсөн устгах",
-    "Last modified" : "Сүүлд өөрчилсөн",
     "Cancel" : "цуцлах",
     "Close" : "Хаах",
+    "Select tags to filter by" : "Хайлт хийх tag-үүдийг сонгоно уу",
+    "Last modified" : "Сүүлд өөрчилсөн",
     "Tomorrow" : "маргааш",
     "Details" : "Дэлгэрэнгүй",
     "Notes" : "Шинэ ",
