@@ -16,6 +16,7 @@ OC.L10N.register(
     "Can edit" : "Pòt modificar",
     "Edit" : "Modificar",
     "Copy private link" : "Copiar lo ligam privat",
+    "Copied" : "Copiat",
     "Export" : "Exportar",
     "Delete" : "Suprimir",
     "Unshare" : "Partejar pas mai",
@@ -26,16 +27,15 @@ OC.L10N.register(
     "Delete permanently" : "Suprimir definitivament",
     "Untitled task" : "Prètzfach sens nom",
     "Untitled event" : "Eveniment sens títol",
+    "Cancel" : "Anullar",
+    "Close" : "Tampar",
     "Alphabetically" : "Alfabeticament",
     "[Yesterday]" : "[Ièr]",
     "[Today]" : "[Uèi]",
     "[Tomorrow]" : "[Deman]",
-    "Cancel" : "Anullar",
-    "Close" : "Tampar",
     "_%n Completed Task_::_%n Completed Tasks_" : ["%n prètzfach acabat","%n prètzfaches acabats"],
     "Tomorrow" : "Deman",
     "All day" : "Tota la jornada",
-    "Edit title" : "Modificar lo títol",
     "Details" : "Detalhs",
     "Notes" : "Nòtas",
     "Reminders" : "Rapèls",
