@@ -42,12 +42,18 @@ OC.L10N.register(
     "Could not load deleted calendars and objects" : "Não foi possível carregar calendários e objetos apagados ",
     "Could not restore calendar or event" : "Não foi possível restaurar o calendário ou evento ",
     "Do you really want to empty the trash bin?" : "Tem a certeza que pretende esvaziar a reciclagem?",
-    "No errors" : "Sem erros",
-    "Open your browser console for more details" : "Abra a consola do seu navegador para obter mais detalhes",
-    "Due date" : "Data limite",
-    "Last modified" : "Última modificação",
     "Cancel" : "Cancelar",
     "Close" : "Fechar",
+    "No errors" : "Sem erros",
+    "Open your browser console for more details" : "Abra a consola do seu navegador para obter mais detalhes",
+    "Select tags to filter by" : "Selecionar etiquetas para filtrar",
+    "Change sort order" : "Alterar ordenação",
+    "Start date" : "Data de início",
+    "Due date" : "Data limite",
+    "Last modified" : "Última modificação",
+    "Priority" : "Prioridade",
+    "Alphabetically" : "Alfabeticamente",
+    "Manually" : "Manual",
     "_%n Completed Task_::_%n Completed Tasks_" : ["%n Tarefa Concluída","%n Tarefas Concluídas","%n Tarefas Concluídas"],
     "Tomorrow" : "Amanhã",
     "All day" : "Todo o dia",
