@@ -8,11 +8,14 @@ OC.L10N.register(
     "Tasks" : "கடமைகள்",
     "Can edit" : "Can edit",
     "Edit" : "தொகுக்க",
+    "Copied" : "நகலெடுக்கப்பட்டது",
+    "Cannot copy" : "நகலெடுக்க முடியாது",
     "Export" : "ஏற்றுமதி",
     "Delete" : "நீக்குக",
     "Unshare" : "பகிரப்படாதது",
-    "Save" : "சேமிக்க ",
     "Name" : "பெயர்",
+    "Restore" : "மீட்டெடு",
+    "Delete permanently" : "நிரந்தரமாக நீக்கவும்",
     "Cancel" : "இரத்து செய்க",
     "Close" : "மூடுக",
     "Details" : "விவரங்கள்",
