@@ -78,6 +78,13 @@ OC.L10N.register(
     "Delete value" : "刪除值",
     "Add this as a new tag" : "將此加入為新標籤",
     "No tag available. Create one!" : "沒有可用的標籤。創建一個！",
+    "Create new tasks" : "創建新任務",
+    "Create {numberOfTasks} tasks from pasted text" : "從貼上的文字建立 {numberOfTasks} 個工作項目",
+    "Cancel" : "取消",
+    "Create tasks" : "創建任務",
+    "Creating new tasks…" : "正在建立新的任務 ...",
+    "Close" : " 關閉",
+    "{numberOfTasks} tasks have been added to \"{calendar}\"" : "{numberOfTasks} 個任務已被新增至「{calendar}」",
     "Delete all completed tasks." : "刪除所有已完成的任務。",
     "Delete completed tasks." : "刪除已完成的任務。",
     "Deleted all completed tasks from calendar \"{calendar}\"." : "從日曆「{calendar}」刪除了所有已完成的任務。",
@@ -85,6 +92,10 @@ OC.L10N.register(
     "Open your browser console for more details" : "開啟您的瀏覽器主控台以取得詳細資訊",
     "_This will delete {taskCount} completed task and its subtasks from calendar \"{calendar}\"._::_This will delete {taskCount} completed tasks and their subtasks from calendar \"{calendar}\"._" : ["這將會從日曆「{calendar}」刪除 {taskCount} 個已完成的任務與其子項目。"],
     "_Could not delete {failedCount} task._::_Could not delete {failedCount} tasks._" : ["無法刪除 {failedCount} 個任務。"],
+    "Active filter" : "有效的過濾器",
+    "Filter by tags" : "以標籤過濾",
+    "Select tags to filter by" : "依照選擇的標籤篩選",
+    "Reset filter" : "重設過濾",
     "Add an important task to \"{calendar}\"…" : "新增重要任務到「{calendar}」……",
     "Add a task due today to \"{calendar}\"…" : "新增今日到期的任務到「{calendar}」…",
     "Add a current task to \"{calendar}\"…" : "新增當前的任務到「{calendar}」…",
@@ -92,6 +103,7 @@ OC.L10N.register(
     "Load the completed tasks of all lists." : "加載所有列表的已完成任務。",
     "Loading the completed tasks of all lists might slow down the app." : "加載所有列表的已完成任務可能會降低應用程式的速度。",
     "Load the completed tasks of list \"{calendar}\"." : "加載「{calendar}」清單的已完成任務。",
+    "Loading the completed tasks might slow down the app." : "載入已完成工作可能會拖慢應用程式的速度。",
     "Change sort order" : "更改排序",
     "Relevance" : "相關性",
     "Sort by completed state, due date, priority, start date and summary." : "按完成狀態、到期日期、優先程度、開始日期與摘要排序。",
@@ -111,11 +123,10 @@ OC.L10N.register(
     "Sort by summary and priority." : "按摘要與優先程度排序。",
     "Manually" : "手動",
     "Sort by manual order." : "手動排序。",
-    "{complete} % completed" : "{complete}% 完成",
     "Task has hidden subtasks" : "任務具有隱藏的子任務",
-    "Task has not yet started" : "任務尚未開始",
     "Task is pinned" : "任務被標記為固定",
     "Task has a note" : "任務有註釋",
+    "{complete} % completed" : "{complete}% 完成",
     "Add subtask" : "新增子任務",
     "Show subtasks" : "顯示子任務",
     "Hide subtasks" : "隱藏子任務",
@@ -145,25 +156,27 @@ OC.L10N.register(
     "Task is not completed" : "任務未完成",
     "Create a new task" : "創建新任務",
     "Task summary" : "任務摘要",
-    "Cancel" : "取消",
     "Create task" : "創建任務",
     "Creating the new task…" : "正在建立新任務...",
-    "Close" : " 關閉",
     "Open task" : "打開任務",
     "\"{task}\" was added to \"{calendar}\"" : "\"{task}\" 已被添加至 \"{calendar}\"",
     "_%n Completed Task_::_%n Completed Tasks_" : ["%n 項已完成的任務"],
     "Tomorrow" : "明日",
     "Add List…" : "增加清單...",
     "New list" : "新清單",
+    "An error occurred, unable to create the list." : "遇到錯誤，無法建立清單。",
     "All day" : "整日",
     "Unpin" : "取消固定",
     "Pin" : "固定",
     "Show in Calendar" : "在日曆上顯示",
-    "Edit title" : "編輯標題",
+    "Show in Deck" : "顯示在 Deck 中",
+    "Edit summary" : "編輯摘要",
     "Details" : "細節",
     "Selecting a classification is forbidden, because the task was shared with you." : "由於任務已與您共享，您無法選擇分類。",
     "Select a classification" : "選擇等級",
     "Select a status" : "選擇狀態",
+    "Set a location" : "設置地點",
+    "Set a URL" : "設置 URL",
     "Select tags" : "選擇標籤",
     "Notes" : "備註",
     "Reminders" : "提醒",
@@ -190,29 +203,7 @@ OC.L10N.register(
     "Clear status" : "清空狀態",
     "Loading task from server." : "正在從伺服器載入任務。",
     "Task not found!" : "找不到任務!",
-    "[Starts today]" : "[今日開始]",
-    "[Starts tomorrow]" : "[昨日開始]",
-    "[Starts on] LL" : "[開始於] LL",
-    "[Started yesterday]" : "[昨日開始]",
-    "[Started on] LL" : "[開始於] LL",
-    "[Started today at] LT" : "[今日開始於] LT",
-    "[Starts today at] LT" : "[今日開始於] LT",
-    "[Starts tomorrow at] LT" : "[明日開始於] LT",
-    "[Starts on] LL [at] LT" : "[開始在] LL [於] LT",
-    "[Started yesterday at] LT" : "[昨日開始於] LT",
-    "[Started on] LL [at] LT" : "[開始在] LL [於] LT",
     "Set start date" : "設定開始日期",
-    "[Due today]" : "[今日到期]",
-    "[Due tomorrow]" : "[明日到期]",
-    "[Due on] LL" : "[到期於] LL",
-    "[Was due yesterday]" : "[昨日到期]",
-    "[Was due on] LL" : "[到期於] LL",
-    "[Was due today at] LT" : "[今日到期於] LT",
-    "[Due today at] LT" : "[今日到期於] LT",
-    "[Due tomorrow at] LT" : "[明日到期於] LT",
-    "[Due on] LL [at] LT" : "[到期於] LL LT",
-    "[Was due yesterday at] LT" : "[昨日到期於] LT",
-    "[Was due on] LL [at] LT" : "[到期在於] LL LT",
     "Set due date" : "設定到期日期",
     "Priority {priority}: low" : "優先程度 {priority}：低",
     "Priority {priority}: medium" : "優先程度 {priority}：中",
@@ -225,8 +216,12 @@ OC.L10N.register(
     "Mark as done" : "標記為完成",
     "No due date assigned" : "未指定截止日期",
     "[Due yesterday]" : "[昨天截止]",
+    "[Due today]" : "[今日到期]",
+    "[Due tomorrow]" : "[明日到期]",
     "[Due] L" : "[截止於] L",
     "[Due yesterday at] LT" : "[截止時間為昨天] LT",
+    "[Due today at] LT" : "[今日到期於] LT",
+    "[Due tomorrow at] LT" : "[明日到期於] LT",
     "[Due] L [at] LT" : "[截止於] L LT",
     "Successfully created the task." : "成功建立任務。",
     "Could not delete the task." : "無法刪除任務。",
@@ -238,6 +233,24 @@ OC.L10N.register(
     "Task successfully moved to new calendar." : "任務成功移到新的日曆。",
     "An error occurred" : "發生錯誤",
     "Create a task" : "創建任務",
-    "Message from {author} in {conversationName}" : "{conversationName} 中來自 {author} 之訊息"
+    "Message from {author} in {conversationName}" : "{conversationName} 中來自 {author} 之訊息",
+    "[Due on] LL" : "[到期於] LL",
+    "[Was due yesterday]" : "[昨日到期]",
+    "[Was due on] LL" : "[到期於] LL",
+    "[Was due today at] LT" : "[今日到期於] LT",
+    "[Due on] LL [at] LT" : "[到期於] LL LT",
+    "[Was due yesterday at] LT" : "[昨日到期於] LT",
+    "[Was due on] LL [at] LT" : "[到期在於] LL LT",
+    "[Starts today]" : "[今日開始]",
+    "[Starts tomorrow]" : "[昨日開始]",
+    "[Starts on] LL" : "[開始於] LL",
+    "[Started yesterday]" : "[昨日開始]",
+    "[Started on] LL" : "[開始於] LL",
+    "[Started today at] LT" : "[今日開始於] LT",
+    "[Starts today at] LT" : "[今日開始於] LT",
+    "[Starts tomorrow at] LT" : "[明日開始於] LT",
+    "[Starts on] LL [at] LT" : "[開始在] LL [於] LT",
+    "[Started yesterday at] LT" : "[昨日開始於] LT",
+    "[Started on] LL [at] LT" : "[開始在] LL [於] LT"
 },
 "nplurals=1; plural=0;");
